/* ============================================================================
 * Copyright (C) 2004 - Infineon Technologies AG.
 *
 * All rights reserved.
 * ============================================================================
 *
 * ============================================================================
 *
 * This document contains proprietary information belonging to Infineon
 * Technologies AG. Passing on and copying of this document, and communication
 * of its contents is not permitted without prior written authorisation.
 *
 * ============================================================================
 */

/* ===========================================================================
 *
 * File Name    : adslAturPerfDataTable_access.c
 * Author       : Subbi
 * Date         : 17-Jun-2004
 *
 * ===========================================================================
 *
 * Project      : Amazon
 * Block        : ADSL-MIBs
 *
 * ===========================================================================
 * Contents: This file contains functions for:
 *                 1) Getting the data context pointer & loop context pointer
 *                 2) User-defined data access functions (per column) for data
 *                    in table adslAturPerfDataTable
 *
 *
 * ===========================================================================
 * References: RFC 2662
 *
 */

/* ===========================================================================
 * Revision History:
 * subramani: Changed the return types for get_adslAturPerfValidIntervals,
 * get_adslAturPerfInvalidIntervals and get_adslAturPerfPrev1DayMoniSecs
 * $Log$
 * ===========================================================================
 */

/*
 * Note: this file originally auto-generated by mib2c using
 *        : mib2c.access_functions.conf,v 1.6 2003/09/11 22:48:49 rstory Exp $
 */

/*
 * ===========================================================================
 *                           INCLUDE FILES
 * ===========================================================================
 */
#include <net-snmp/net-snmp-config.h>
#include <net-snmp/net-snmp-includes.h>
#include <net-snmp/agent/net-snmp-agent-includes.h>
#include "adslAturPerfDataTable_access.h"
#ifdef STUB_IOCTL
#include "adslAturPerfDataTable_enums.h"
#endif


/* column number definitions for table adslAturPerfDataTable */
#include "adslAturPerfDataTable_columns.h"

/*
 * ===========================================================================
 *                           GLOBAL DEFINITIONS
 * ===========================================================================
 */
// *** Global variable definitions
static long long_ret;

/*
 * ===========================================================================
 *                           LOCAL FUNCTIONS
 * ===========================================================================
 */


/** returns the first data point within the adslAturPerfDataTable table data.

    Set the my_loop_context variable to the first data point structure
    of your choice (from which you can find the next one).  This could
    be anything from the first node in a linked list, to an integer
    pointer containing the beginning of an array variable.

    Set the my_data_context variable to something to be returned to
    you later that will provide you with the data to return in a given
    row.  This could be the same pointer as what my_loop_context is
    set to, or something different.

    The put_index_data variable contains a list of snmp variable
    bindings, one for each index in your table.  Set the values of
    each appropriately according to the data matching the first row
    and return the put_index_data variable at the end of the function.
*/
netsnmp_variable_list *
adslAturPerfDataTable_get_first_data_point(void **my_loop_context,
                                           void **my_data_context,
                                           netsnmp_variable_list *
                                           put_index_data,
                                           netsnmp_iterator_info *mydata)
{

    int *My_Data_Context;
    My_Data_Context = SNMP_MALLOC_TYPEDEF(int);
    if (!My_Data_Context) {
        put_index_data = NULL;
        snmp_log(LOG_ERR, "Get-First: adslAturPerfDataTable: My_Data_Context malloc failed\n");
        return put_index_data;
    }

    *My_Data_Context=IFTYPE_ADSL;
    *my_data_context=My_Data_Context;

    put_index_data = adslTable_get_first_data_point(my_loop_context,
                                   my_data_context,
                                   put_index_data,
                                   mydata);

    SNMP_FREE(My_Data_Context);
    return put_index_data;
}

/** functionally the same as adslAturPerfDataTable_get_first_data_point, but
   my_loop_context has already been set to a previous value and should
   be updated to the next in the list.  For example, if it was a
   linked list, you might want to cast it to your local data type and
   then return my_loop_context->next.  The my_data_context pointer
   should be set to something you need later and the indexes in
   put_index_data updated again. */
netsnmp_variable_list *
adslAturPerfDataTable_get_next_data_point(void **my_loop_context,
                                          void **my_data_context,
                                          netsnmp_variable_list *
                                          put_index_data,
                                          netsnmp_iterator_info *mydata)
{

    int *My_Data_Context;
    My_Data_Context = SNMP_MALLOC_TYPEDEF(int);
    if (!My_Data_Context) {
        put_index_data = NULL;
        snmp_log(LOG_ERR, "Get-Next: adslAtucPerfDataTable: My_Data_Context malloc failed\n");
        return put_index_data;
    }

    *My_Data_Context=IFTYPE_ADSL;
    *my_data_context=My_Data_Context;

     put_index_data = adslTable_get_next_data_point(my_loop_context,
                                   my_data_context,
                                   put_index_data,
                                   mydata);

    SNMP_FREE(My_Data_Context);
    return put_index_data;
}

/*
 * User-defined data access functions (per column) for data in table
   adslAturPerfDataTable */
/*
 * NOTE:
 * - these get_ routines MUST return data that will not be freed (ie,
 *   use static variables or persistent data).  It will be copied, if
 *   needed, immediately after the get_ routine has been called.
 * - these SET routines must copy the incoming data and can not take
 *   ownership of the memory passed in by the val pointer.
 */

#if defined(HAVE_OPTIMIZED_CODE)

u_int32  *
get_adslAturPerfDataLoss(void *data_context, size_t * ret_len,
			unsigned int var)
{
  unsigned int flags = 0;
  struct aturPerfDataEntry aturPerfDataEntryStruct;
  memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
  aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
  
  switch (var)  {

	case COLUMN_ADSLATURPERFLOFS:
	   flags = ATUR_PERF_LOFS_FLAG;
	   break;

	case COLUMN_ADSLATURPERFLOSS:
	   flags = ATUR_PERF_LOSS_FLAG;
	   break;

	case COLUMN_ADSLATURPERFLPRS:
	   flags = ATUR_PERF_LPR_FLAG;
	   break;

	case COLUMN_ADSLATURPERFESS:
	   flags = ATUR_PERF_ESS_FLAG;
	   break;

     	default:
     	   DEBUGMSGTL(("Unknown MIB variable requested!", "\n"));
     	   return NULL;
  }

  SET_FLAG(&aturPerfDataEntryStruct.flags, flags);
#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
            (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags, flags) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataTable: GET- %x CMV fail\n", flags));

    switch (flags)  {
	    
	case ATUR_PERF_LOFS_FLAG:
    	   long_ret = aturPerfDataEntryStruct.adslAturPerfLofs;
	   break;

	case ATUR_PERF_LOSS_FLAG:
    	   long_ret = aturPerfDataEntryStruct.adslAturPerfLoss;
	   break;

	case ATUR_PERF_LPR_FLAG:
    	   long_ret = aturPerfDataEntryStruct.adslAturPerfLprs;
	   break;

	case ATUR_PERF_ESS_FLAG:
    	   long_ret = aturPerfDataEntryStruct.adslAturPerfESs;
	   break;
		
        default:
     	    DEBUGMSGTL(("Unknown MIB variable requested!", "\n"));
            return NULL;
    }
    
    CLR_FLAG(&aturPerfDataEntryStruct.flags, flags);
    *ret_len = sizeof(u_int32);
    return (u_int32 *) &long_ret;
}


int *
get_adslAturPerfIntervalData(void *data_context, size_t * ret_len,
			unsigned int var)
{
  unsigned int flags = 0;
  struct aturPerfDataEntry aturPerfDataEntryStruct;
  memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
  aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);

  switch (var) {

      case COLUMN_ADSLATURPERFVALIDINTERVALS:
	 flags = ATUR_PERF_VALID_INTVLS_FLAG;
	 break;
	 
      case COLUMN_ADSLATURPERFINVALIDINTERVALS:
	 flags = ATUR_PERF_INVALID_INTVLS_FLAG;
	 break;

      case COLUMN_ADSLATURPERFPREV1DAYMONISECS:
	 flags = ATUR_PERF_PREV_1DAY_MON_SEC_FLAG;
	 break;
	 
      default:
     	 DEBUGMSGTL(("Unknown MIB variable requested!", "\n"));
     	 return NULL;
 }
  
  SET_FLAG(&aturPerfDataEntryStruct.flags, flags);
#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
            (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags, flags) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataTable: GET- %x CMV fail\n", flags));

    switch (flags)  {
	    
	case ATUR_PERF_VALID_INTVLS_FLAG:
    	   long_ret = aturPerfDataEntryStruct.adslAturPerfValidIntervals;
	   break;

	case ATUR_PERF_INVALID_INTVLS_FLAG:
    	   long_ret = aturPerfDataEntryStruct.adslAturPerfInvalidIntervals;
	   break;

	case ATUR_PERF_PREV_1DAY_MON_SEC_FLAG:
    	   long_ret = aturPerfDataEntryStruct.adslAturPerfPrev1DayMoniSecs;
	   break;

        default:
     	    DEBUGMSGTL(("Unknown MIB variable requested!", "\n"));
            return NULL;
    }
    
    CLR_FLAG(&aturPerfDataEntryStruct.flags, flags);
    *ret_len = sizeof(int);
    return (int *) &long_ret;
}


u_int32  *
get_adslAturPerfDataStats(void *data_context, size_t * ret_len,
			unsigned int var)
{
  unsigned int flags = 0;
  struct aturPerfDataEntry aturPerfDataEntryStruct;
  memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
  aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);

  switch (var) {

      case COLUMN_ADSLATURPERFCURR15MINTIMEELAPSED:
	 flags = ATUR_PERF_CURR_15MIN_TIME_ELAPSED_FLAG; 
         break;
	 
      case COLUMN_ADSLATURPERFCURR15MINLOFS:
	 flags = ATUR_PERF_CURR_15MIN_LOFS_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFCURR15MINLOSS:
	 flags = ATUR_PERF_CURR_15MIN_LOSS_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFCURR15MINLPRS:
	 flags = ATUR_PERF_CURR_15MIN_LPR_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFCURR15MINESS:
	 flags = ATUR_PERF_CURR_15MIN_ESS_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFCURR1DAYTIMEELAPSED:
	 flags = ATUR_PERF_CURR_1DAY_TIME_ELAPSED_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFCURR1DAYLOFS:
	 flags = ATUR_PERF_CURR_1DAY_LOFS_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFCURR1DAYLOSS:
	 flags = ATUR_PERF_CURR_1DAY_LOSS_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFCURR1DAYLPRS:
	 flags = ATUR_PERF_CURR_1DAY_LPR_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFCURR1DAYESS:
	 flags = ATUR_PERF_CURR_1DAY_ESS_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFPREV1DAYLOFS:
	 flags = ATUR_PERF_PREV_1DAY_LOFS_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFPREV1DAYLOSS:
	 flags = ATUR_PERF_PREV_1DAY_LOSS_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFPREV1DAYLPRS:
	 flags = ATUR_PERF_PREV_1DAY_LPR_FLAG;
	 break;
	  
      case COLUMN_ADSLATURPERFPREV1DAYESS:
	 flags = ATUR_PERF_PREV_1DAY_ESS_FLAG;
	 break;
	 
      default:
     	 DEBUGMSGTL(("Unknown MIB variable requested!", "\n"));
         return NULL;
 }

  SET_FLAG(&aturPerfDataEntryStruct.flags, flags);
#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
            (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags, flags) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataTable: GET- %x CMV fail\n", flags));

     switch (flags)  {

	 case ATUR_PERF_CURR_15MIN_TIME_ELAPSED_FLAG:
	    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr15MinTimeElapsed;
            break;
	 
	 case ATUR_PERF_CURR_15MIN_LOFS_FLAG:
	    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr15MinLofs;
	    break;
	  
	 case ATUR_PERF_CURR_15MIN_LOSS_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr15MinLoss;
	    break;
	  
	 case ATUR_PERF_CURR_15MIN_LPR_FLAG:
    	    long_ret =  aturPerfDataEntryStruct.adslAturPerfCurr15MinLprs;
	    break;
	  
	 case ATUR_PERF_CURR_15MIN_ESS_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr15MinESs;
	    break;
	  
	 case ATUR_PERF_CURR_1DAY_TIME_ELAPSED_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr1DayTimeElapsed;
	    break;
	  
	 case ATUR_PERF_CURR_1DAY_LOFS_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr1DayLofs;
	    break;
	  
	 case ATUR_PERF_CURR_1DAY_LOSS_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr1DayLoss;
	    break;
	  
	 case ATUR_PERF_CURR_1DAY_LPR_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr1DayLprs;
            break;
	  
	 case ATUR_PERF_CURR_1DAY_ESS_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr1DayESs;
	    break;
	  
	 case ATUR_PERF_PREV_1DAY_LOFS_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfPrev1DayLofs;
	    break;
	  
	 case ATUR_PERF_PREV_1DAY_LOSS_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfPrev1DayLoss;
	    break;
	  
	 case ATUR_PERF_PREV_1DAY_LPR_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfPrev1DayLprs;
	    break;
	  
	 case ATUR_PERF_PREV_1DAY_ESS_FLAG:
    	    long_ret = aturPerfDataEntryStruct.adslAturPerfPrev1DayESs;
	    break;
	 
         default:
     	    DEBUGMSGTL(("Unknown MIB variable requested!", "\n"));
            return NULL;
     }
     
    CLR_FLAG(&aturPerfDataEntryStruct.flags, flags);
    *ret_len = sizeof(u_int32);
    return (u_int32 *) &long_ret;
}

#else

/** XXX: return a data pointer to the data for the adslAturPerfLofs column
    and set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfLofs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_LOFS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
                (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags, ATUR_PERF_LOFS_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataLOFS CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_LOFS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfLofs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfLofs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfLoss column and
    set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfLoss(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_LOSS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
                (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags, ATUR_PERF_LOSS_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataLOSS CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_LOSS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfLoss;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfLoss);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfLprs column and
    set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfLprs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_LPR_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
                (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags, ATUR_PERF_LPR_FLAG) == 0)
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataLPRS CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_LPR_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfLprs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfLprs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfESs column and
    set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfESs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_ESS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
            (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags, ATUR_PERF_ESS_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataESS CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_ESS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfESs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfESs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfValidIntervals
    column and set ret_len to its proper size in bytes. */
int           *
get_adslAturPerfValidIntervals(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_VALID_INTVLS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
            (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
            ATUR_PERF_VALID_INTVLS_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataValidIntvl CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_VALID_INTVLS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfValidIntervals;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfValidIntervals);
    return (int *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfInvalidIntervals
    column and set ret_len to its proper size in bytes. */
int           *
get_adslAturPerfInvalidIntervals(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_INVALID_INTVLS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
            (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
            ATUR_PERF_INVALID_INTVLS_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataInvalidIntvl CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_INVALID_INTVLS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfInvalidIntervals;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfInvalidIntervals);
    return (int *) &long_ret;
}

/** XXX: return a data pointer to the data for the
    adslAturPerfCurr15MinTimeElapsed column and set ret_len to its proper size
    in bytes. */
u_int32         *
get_adslAturPerfCurr15MinTimeElapsed(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

   memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags,
        ATUR_PERF_CURR_15MIN_TIME_ELAPSED_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
                (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
            ATUR_PERF_CURR_15MIN_TIME_ELAPSED_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataCurr15Min CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags,
            ATUR_PERF_CURR_15MIN_TIME_ELAPSED_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr15MinTimeElapsed;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfCurr15MinTimeElapsed);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfCurr15MinLofs
    column and set ret_len to its proper size in bytes. */
u_int32      *
get_adslAturPerfCurr15MinLofs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_15MIN_LOFS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
            (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
            ATUR_PERF_CURR_15MIN_LOFS_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataCurr15MinLOF CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_15MIN_LOFS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr15MinLofs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfCurr15MinLofs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfCurr15MinLoss
    column and set ret_len to its proper size in bytes. */
u_int32      *
get_adslAturPerfCurr15MinLoss(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_15MIN_LOSS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
            (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
            ATUR_PERF_CURR_15MIN_LOSS_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataCurr15MinLOSS CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_15MIN_LOSS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr15MinLoss;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfCurr15MinLoss);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfCurr15MinLprs
    column and set ret_len to its proper size in bytes. */
u_int32      *
get_adslAturPerfCurr15MinLprs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_15MIN_LPR_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
           ATUR_PERF_CURR_15MIN_LPR_FLAG) == 0) 
      DEBUGMSGTL(("adslMIB-ATUR", "PerfDataCurr15MinLOSS CMV fail\n"));
    
    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_15MIN_LPR_FLAG);
    long_ret =  aturPerfDataEntryStruct.adslAturPerfCurr15MinLprs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfCurr15MinLprs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfCurr15MinESs
    column and set ret_len to its proper size in bytes. */
u_int32      *
get_adslAturPerfCurr15MinESs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_15MIN_ESS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
        ATUR_PERF_CURR_15MIN_ESS_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataCurr15MinESS CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_15MIN_ESS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr15MinESs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfCurr15MinESs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the
    adslAturPerfCurr1DayTimeElapsed column and set ret_len to its proper
    size in bytes. */
u_int32         *
get_adslAturPerfCurr1DayTimeElapsed(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags,
        ATUR_PERF_CURR_1DAY_TIME_ELAPSED_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
        ATUR_PERF_CURR_1DAY_TIME_ELAPSED_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataCurr1DayElapse CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags,
        ATUR_PERF_CURR_1DAY_TIME_ELAPSED_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr1DayTimeElapsed;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfCurr1DayTimeElapsed);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfCurr1DayLofs
    column and set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfCurr1DayLofs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_1DAY_LOFS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
        ATUR_PERF_CURR_1DAY_LOFS_FLAG) == 0) 
     DEBUGMSGTL(("adslMIB-ATUR", "PerfDataCurr1DayLOF CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_1DAY_LOFS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr1DayLofs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfCurr1DayLofs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfCurr1DayLoss
    column and set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfCurr1DayLoss(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_1DAY_LOSS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
        ATUR_PERF_CURR_1DAY_LOSS_FLAG) == 0) 
     DEBUGMSGTL(("adslMIB-ATUR", "PerfDataCurr1DayLOSS CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_1DAY_LOSS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr1DayLoss;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfCurr1DayLoss);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfCurr1DayLprs
    column and set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfCurr1DayLprs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_1DAY_LPR_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
            ATUR_PERF_CURR_1DAY_LPR_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataCurr1DayLPR CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_1DAY_LPR_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr1DayLprs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfCurr1DayLprs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfCurr1DayESs
    column and set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfCurr1DayESs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_1DAY_ESS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
                ATUR_PERF_CURR_1DAY_ESS_FLAG) == 0) 
     DEBUGMSGTL(("adslMIB-ATUR", "PerfDataCurr1DayESS CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_CURR_1DAY_ESS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfCurr1DayESs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfCurr1DayESs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfPrev1DayMoniSecs
    column and set ret_len to its proper size in bytes. */
int           *
get_adslAturPerfPrev1DayMoniSecs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_PREV_1DAY_MON_SEC_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
        ATUR_PERF_PREV_1DAY_MON_SEC_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataPrev1DayMonSec CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_PREV_1DAY_MON_SEC_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfPrev1DayMoniSecs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfPrev1DayMoniSecs);
    return (int *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfPrev1DayLofs
    column and set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfPrev1DayLofs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_PREV_1DAY_LOFS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
        ATUR_PERF_PREV_1DAY_LOFS_FLAG) == 0) 
       DEBUGMSGTL(("adslMIB-ATUR", "PerfDataPrev1DayLOF CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_PREV_1DAY_LOFS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfPrev1DayLofs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfPrev1DayLofs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfPrev1DayLoss
    column and set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfPrev1DayLoss(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_PREV_1DAY_LOSS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
        ATUR_PERF_PREV_1DAY_LOSS_FLAG) == 0) 
     DEBUGMSGTL(("adslMIB-ATUR", "PerfDataPrev1DayLOSS CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_PREV_1DAY_LOSS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfPrev1DayLoss;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfPrev1DayLoss);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfPrev1DayLprs
    column and set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfPrev1DayLprs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_PREV_1DAY_LPR_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
            ATUR_PERF_PREV_1DAY_LPR_FLAG) == 0) 
     DEBUGMSGTL(("adslMIB-ATUR", "PerfDataPrev1DayLPR CMV fail\n"));

    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_PREV_1DAY_LPR_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfPrev1DayLprs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfPrev1DayLprs);
    return (u_int32 *) &long_ret;
}

/** XXX: return a data pointer to the data for the adslAturPerfPrev1DayESs
    column and set ret_len to its proper size in bytes. */
u_int32         *
get_adslAturPerfPrev1DayESs(void *data_context, size_t * ret_len)
{
    struct aturPerfDataEntry aturPerfDataEntryStruct;

    memset(&aturPerfDataEntryStruct,0,sizeof(aturPerfDataEntry));
    aturPerfDataEntryStruct.ifIndex= (*(int *)data_context);
    SET_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_PREV_1DAY_ESS_FLAG);

#ifdef ENABLE_DRIVER_CALL
    adsl_ioctl(Fd, GET_ADSL_ATUR_PERF_DATA, (void *) &aturPerfDataEntryStruct);
#else
    get_adslAturPerfDataTable(Fd, GET_ADSL_ATUR_PERF_DATA,
        (void *) &aturPerfDataEntryStruct);
#endif
    if (IS_FLAG_SET(&aturPerfDataEntryStruct.flags,
                ATUR_PERF_PREV_1DAY_ESS_FLAG) == 0) 
      DEBUGMSGTL(("adslMIB-ATUR", "PerfDataPrev1DayESS CMV fail\n"));
     
    CLR_FLAG(&aturPerfDataEntryStruct.flags, ATUR_PERF_PREV_1DAY_ESS_FLAG);
    long_ret = aturPerfDataEntryStruct.adslAturPerfPrev1DayESs;
    *ret_len = sizeof(aturPerfDataEntryStruct.adslAturPerfPrev1DayESs);
    return (u_int32 *) &long_ret;
}
#endif


#ifndef ENABLE_DRIVER_CALL
int get_adslAturPerfDataTable(int Fd2,int GET_adsl_ATUR_PERF_DATA2,
                void *aturPerfDataValue)
{

    struct aturPerfDataEntry *aturPerfData;
    aturPerfData = (aturPerfDataEntry *) aturPerfDataValue;
    aturPerfData->adslAturPerfLofs = 10;
    aturPerfData->adslAturPerfLoss = 20;
    aturPerfData->adslAturPerfLprs = 30;
    aturPerfData->adslAturPerfESs = 40;
    aturPerfData->adslAturPerfValidIntervals = 10;
    aturPerfData->adslAturPerfInvalidIntervals = 20;
    aturPerfData->adslAturPerfCurr15MinTimeElapsed = 10;
    aturPerfData->adslAturPerfCurr15MinLofs = 15;
    aturPerfData->adslAturPerfCurr15MinLoss = 20;
    aturPerfData->adslAturPerfCurr15MinLprs = 25;
    aturPerfData->adslAturPerfCurr15MinESs = 30;
    aturPerfData->adslAturPerfCurr1DayTimeElapsed = 40;
    aturPerfData->adslAturPerfCurr1DayLofs = 50;
    aturPerfData->adslAturPerfCurr1DayLoss = 60;
    aturPerfData->adslAturPerfCurr1DayLprs = 65;
    aturPerfData->adslAturPerfCurr1DayESs = 70;
    aturPerfData->adslAturPerfPrev1DayMoniSecs = 80;
    aturPerfData->adslAturPerfPrev1DayLofs = 85;
    aturPerfData->adslAturPerfPrev1DayLoss = 90;
    aturPerfData->adslAturPerfPrev1DayLprs = 95;
    aturPerfData->adslAturPerfPrev1DayESs = 100;

    return 0;
}
#endif

