/*
 *  Linux kernel interface
 *
 */

#include <net-snmp/net-snmp-config.h>
#include <net-snmp/net-snmp-includes.h>
#include <net-snmp/agent/net-snmp-agent-includes.h>

#include "util_funcs.h"

#if HAVE_STRING_H
#include <string.h>
#endif
#include <sys/types.h>
#if HAVE_SYS_PARAM_H
#include <sys/param.h>
#endif

#include "kernel_linux.h"

#if defined(HAVE_CACHE_SUPPORT)
struct ip_mib   cached_ip_mib;
struct icmp_mib cached_icmp_mib;
struct tcp_mib  cached_tcp_mib;
struct udp_mib  cached_udp_mib;
#endif

#define IP_STATS_LINE   "Ip: %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu"
#define ICMP_STATS_LINE "Icmp: %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu"
#define TCP_STATS_LINE  "Tcp: %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu"
#define UDP_STATS_LINE  "Udp: %lu %lu %lu %lu"

#define IP_STATS_PREFIX_LEN 4
#define ICMP_STATS_PREFIX_LEN   6
#define TCP_STATS_PREFIX_LEN    5
#define UDP_STATS_PREFIX_LEN    5

#if defined(HAVE_OPTIMIZED_CODE)
int
linux_read_mibII_stats_opt(void **mib2struct, unsigned int proto)
{
    FILE           *in = fopen("/proc/net/snmp", "r");
    char            line[1024];

    struct ip_mib   *ifx_ip_mib;
    struct icmp_mib *ifx_icmp_mib;
    struct tcp_mib  *ifx_tcp_mib;
    struct udp_mib  *ifx_udp_mib;
    int             ret;

    if (!in) {
        return -1;
    }


    while (line == fgets(line, sizeof(line), in)) {
    switch (proto) {

     case IFX_IP_STATS:
            if (!strncmp(line, IP_STATS_LINE, IP_STATS_PREFIX_LEN)) {
         ifx_ip_mib =(struct ip_mib *)(*mib2struct);
                sscanf(line, IP_STATS_LINE,
                   &(ifx_ip_mib->ipForwarding),
                   &(ifx_ip_mib->ipDefaultTTL),
                   &(ifx_ip_mib->ipInReceives),
                   &(ifx_ip_mib->ipInHdrErrors),
                   &(ifx_ip_mib->ipInAddrErrors),
                   &(ifx_ip_mib->ipForwDatagrams),
                   &(ifx_ip_mib->ipInUnknownProtos),
                   &(ifx_ip_mib->ipInDiscards),
                   &(ifx_ip_mib->ipInDelivers),
                   &(ifx_ip_mib->ipOutRequests),
                   &(ifx_ip_mib->ipOutDiscards),
                   &(ifx_ip_mib->ipOutNoRoutes),
                   &(ifx_ip_mib->ipReasmTimeout),
                   &(ifx_ip_mib->ipReasmReqds),
                   &(ifx_ip_mib->ipReasmOKs),
                   &(ifx_ip_mib->ipReasmFails),
                   &(ifx_ip_mib->ipFragOKs),
                   &(ifx_ip_mib->ipFragFails),
                   &(ifx_ip_mib->ipFragCreates));
            ifx_ip_mib->ipRoutingDiscards = 0;        /* XXX */

            }
        break;

     case IFX_ICMP_STATS:
        if (!strncmp(line, ICMP_STATS_LINE, ICMP_STATS_PREFIX_LEN)) {
         ifx_icmp_mib =(struct icmp_mib *)(*mib2struct);
            sscanf(line, ICMP_STATS_LINE,
                   &(ifx_icmp_mib->icmpInMsgs),
                   &(ifx_icmp_mib->icmpInErrors),
                   &(ifx_icmp_mib->icmpInDestUnreachs),
                   &(ifx_icmp_mib->icmpInTimeExcds),
                   &(ifx_icmp_mib->icmpInParmProbs),
                   &(ifx_icmp_mib->icmpInSrcQuenchs),
                   &(ifx_icmp_mib->icmpInRedirects),
                   &(ifx_icmp_mib->icmpInEchos),
                   &(ifx_icmp_mib->icmpInEchoReps),
                   &(ifx_icmp_mib->icmpInTimestamps),
                   &(ifx_icmp_mib->icmpInTimestampReps),
                   &(ifx_icmp_mib->icmpInAddrMasks),
                   &(ifx_icmp_mib->icmpInAddrMaskReps),
                   &(ifx_icmp_mib->icmpOutMsgs),
                   &(ifx_icmp_mib->icmpOutErrors),
                   &(ifx_icmp_mib->icmpOutDestUnreachs),
                   &(ifx_icmp_mib->icmpOutTimeExcds),
                   &(ifx_icmp_mib->icmpOutParmProbs),
                   &(ifx_icmp_mib->icmpOutSrcQuenchs),
                   &(ifx_icmp_mib->icmpOutRedirects),
                   &(ifx_icmp_mib->icmpOutEchos),
                   &(ifx_icmp_mib->icmpOutEchoReps),
                   &(ifx_icmp_mib->icmpOutTimestamps),
                   &(ifx_icmp_mib->icmpOutTimestampReps),
                   &(ifx_icmp_mib->icmpOutAddrMasks),
                   &(ifx_icmp_mib->icmpOutAddrMaskReps));
        }
        break;

     case IFX_TCP_STATS:

        if (!strncmp(line, TCP_STATS_LINE, TCP_STATS_PREFIX_LEN)) {
            ifx_tcp_mib =(struct tcp_mib *)(*mib2struct);
                          ret = sscanf(line, TCP_STATS_LINE,
                                         &(ifx_tcp_mib->tcpRtoAlgorithm),
                                         &(ifx_tcp_mib->tcpRtoMin),
                                         &(ifx_tcp_mib->tcpRtoMax),
                                         &(ifx_tcp_mib->tcpMaxConn),
                                         &(ifx_tcp_mib->tcpActiveOpens),
                                         &(ifx_tcp_mib->tcpPassiveOpens),
                                         &(ifx_tcp_mib->tcpAttemptFails),
                                         &(ifx_tcp_mib->tcpEstabResets),
                                         &(ifx_tcp_mib->tcpCurrEstab),
                                         &(ifx_tcp_mib->tcpInSegs),
                                         &(ifx_tcp_mib->tcpOutSegs),
                                         &(ifx_tcp_mib->tcpRetransSegs),
                                         &(ifx_tcp_mib->tcpInErrs),
                                         &(ifx_tcp_mib->tcpOutRsts));
            ifx_tcp_mib->tcpInErrsValid = (ret > 12) ? 1 : 0;
            ifx_tcp_mib->tcpOutRstsValid = (ret > 13) ? 1 : 0;
        }
        break;

     case IFX_UDP_STATS:

        if (!strncmp(line, UDP_STATS_LINE, UDP_STATS_PREFIX_LEN)) {
            ifx_udp_mib =(struct udp_mib *)(*mib2struct);
            sscanf(line, UDP_STATS_LINE,
                   &(ifx_udp_mib->udpInDatagrams),
                   &(ifx_udp_mib->udpNoPorts),
                   &(ifx_udp_mib->udpInErrors),
                   &(ifx_udp_mib->udpOutDatagrams));
        }
    }

    }
    fclose(in);

    /*
     * Tweak illegal values:
     *
     * valid values for ipForwarding are 1 == yup, 2 == nope
     * a 0 is forbidden, so patch:
     */
     if ( proto == IFX_IP_STATS)
        if (!ifx_ip_mib->ipForwarding)
            ifx_ip_mib->ipForwarding = 2;
    /*
     * 0 is illegal for tcpRtoAlgorithm
     * so assume `other' algorithm:
     */
     if ( proto == IFX_TCP_STATS)
        if (!ifx_tcp_mib->tcpRtoAlgorithm)
            ifx_tcp_mib->tcpRtoAlgorithm = 1;

    return 0;
}

#endif

#if defined(HAVE_CACHE_SUPPORT)

int
linux_read_mibII_stats(void)
{
    FILE           *in = fopen("/proc/net/snmp", "r");
    char            line[1024];

    if (!in) {
        return -1;
    }


    while (line == fgets(line, sizeof(line), in)) {
        if (!strncmp(line, IP_STATS_LINE, IP_STATS_PREFIX_LEN)) {
            sscanf(line, IP_STATS_LINE,
                   &cached_ip_mib.ipForwarding,
                   &cached_ip_mib.ipDefaultTTL,
                   &cached_ip_mib.ipInReceives,
                   &cached_ip_mib.ipInHdrErrors,
                   &cached_ip_mib.ipInAddrErrors,
                   &cached_ip_mib.ipForwDatagrams,
                   &cached_ip_mib.ipInUnknownProtos,
                   &cached_ip_mib.ipInDiscards,
                   &cached_ip_mib.ipInDelivers,
                   &cached_ip_mib.ipOutRequests,
                   &cached_ip_mib.ipOutDiscards,
                   &cached_ip_mib.ipOutNoRoutes,
                   &cached_ip_mib.ipReasmTimeout,
                   &cached_ip_mib.ipReasmReqds,
                   &cached_ip_mib.ipReasmOKs,
                   &cached_ip_mib.ipReasmFails,
                   &cached_ip_mib.ipFragOKs,
                   &cached_ip_mib.ipFragFails,
                   &cached_ip_mib.ipFragCreates);
            cached_ip_mib.ipRoutingDiscards = 0;        /* XXX */
        } else if (!strncmp(line, ICMP_STATS_LINE, ICMP_STATS_PREFIX_LEN)) {
            sscanf(line, ICMP_STATS_LINE,
                   &cached_icmp_mib.icmpInMsgs,
                   &cached_icmp_mib.icmpInErrors,
                   &cached_icmp_mib.icmpInDestUnreachs,
                   &cached_icmp_mib.icmpInTimeExcds,
                   &cached_icmp_mib.icmpInParmProbs,
                   &cached_icmp_mib.icmpInSrcQuenchs,
                   &cached_icmp_mib.icmpInRedirects,
                   &cached_icmp_mib.icmpInEchos,
                   &cached_icmp_mib.icmpInEchoReps,
                   &cached_icmp_mib.icmpInTimestamps,
                   &cached_icmp_mib.icmpInTimestampReps,
                   &cached_icmp_mib.icmpInAddrMasks,
                   &cached_icmp_mib.icmpInAddrMaskReps,
                   &cached_icmp_mib.icmpOutMsgs,
                   &cached_icmp_mib.icmpOutErrors,
                   &cached_icmp_mib.icmpOutDestUnreachs,
                   &cached_icmp_mib.icmpOutTimeExcds,
                   &cached_icmp_mib.icmpOutParmProbs,
                   &cached_icmp_mib.icmpOutSrcQuenchs,
                   &cached_icmp_mib.icmpOutRedirects,
                   &cached_icmp_mib.icmpOutEchos,
                   &cached_icmp_mib.icmpOutEchoReps,
                   &cached_icmp_mib.icmpOutTimestamps,
                   &cached_icmp_mib.icmpOutTimestampReps,
                   &cached_icmp_mib.icmpOutAddrMasks,
                   &cached_icmp_mib.icmpOutAddrMaskReps);
        } else if (!strncmp(line, TCP_STATS_LINE, TCP_STATS_PREFIX_LEN)) {
            int             ret = sscanf(line, TCP_STATS_LINE,
                                         &cached_tcp_mib.tcpRtoAlgorithm,
                                         &cached_tcp_mib.tcpRtoMin,
                                         &cached_tcp_mib.tcpRtoMax,
                                         &cached_tcp_mib.tcpMaxConn,
                                         &cached_tcp_mib.tcpActiveOpens,
                                         &cached_tcp_mib.tcpPassiveOpens,
                                         &cached_tcp_mib.tcpAttemptFails,
                                         &cached_tcp_mib.tcpEstabResets,
                                         &cached_tcp_mib.tcpCurrEstab,
                                         &cached_tcp_mib.tcpInSegs,
                                         &cached_tcp_mib.tcpOutSegs,
                                         &cached_tcp_mib.tcpRetransSegs,
                                         &cached_tcp_mib.tcpInErrs,
                                         &cached_tcp_mib.tcpOutRsts);
            cached_tcp_mib.tcpInErrsValid = (ret > 12) ? 1 : 0;
            cached_tcp_mib.tcpOutRstsValid = (ret > 13) ? 1 : 0;
        } else if (!strncmp(line, UDP_STATS_LINE, UDP_STATS_PREFIX_LEN)) {
            sscanf(line, UDP_STATS_LINE,
                   &cached_udp_mib.udpInDatagrams,
                   &cached_udp_mib.udpNoPorts,
                   &cached_udp_mib.udpInErrors,
                   &cached_udp_mib.udpOutDatagrams);
        }
    }
    fclose(in);

    /*
     * Tweak illegal values:
     *
     * valid values for ipForwarding are 1 == yup, 2 == nope
     * a 0 is forbidden, so patch:
     */
    if (!cached_ip_mib.ipForwarding)
        cached_ip_mib.ipForwarding = 2;

    /*
     * 0 is illegal for tcpRtoAlgorithm
     * so assume `other' algorithm:
     */
    if (!cached_tcp_mib.tcpRtoAlgorithm)
        cached_tcp_mib.tcpRtoAlgorithm = 1;
    return 0;
}

int
linux_read_ip_stat(struct ip_mib *ipstat)
{
    memset((char *) ipstat, (0), sizeof(*ipstat));
    if (linux_read_mibII_stats() == -1)
        return -1;
    memcpy((char *) ipstat, (char *) &cached_ip_mib, sizeof(*ipstat));
    return 0;
}

int
linux_read_icmp_stat(struct icmp_mib *icmpstat)
{
    memset((char *) icmpstat, (0), sizeof(*icmpstat));
    if (linux_read_mibII_stats() == -1)
        return -1;
    memcpy((char *) icmpstat, (char *) &cached_icmp_mib,
           sizeof(*icmpstat));
    return 0;
}

int
linux_read_tcp_stat(struct tcp_mib *tcpstat)
{
    memset((char *) tcpstat, (0), sizeof(*tcpstat));
    if (linux_read_mibII_stats() == -1)
        return -1;
    memcpy((char *) tcpstat, (char *) &cached_tcp_mib, sizeof(*tcpstat));
    return 0;
}

int
linux_read_udp_stat(struct udp_mib *udpstat)
{
    memset((char *) udpstat, (0), sizeof(*udpstat));
    if (linux_read_mibII_stats() == -1)
        return -1;
    memcpy((char *) udpstat, (char *) &cached_udp_mib, sizeof(*udpstat));
    return 0;
}
#endif
